@@ -9,7 +9,7 @@ int do_attribute(Attribute *attr, ComponentID cid, int validate);
 
 /* --------------- functions in cwb_encode.c ------------------------------ */
 
-typedef struct _Range Range;
+typedef struct _SAttEncoder SAttEncoder;
 char * encode_strtok(char *s, const char *delim);
 void encode_print_time(char *msg);
 void encode_usage(void);
@@ -17,10 +17,10 @@ void encode_print_input_lineno(void);
 void encode_error(char *format, ...);
 cl_string_list encode_scan_directory(char *dir);
 int range_find(char *name);
-void range_print_registry_line(Range *rng, FILE *fd, int print_comment);
-Range *range_declare(char *name, char *directory, int store_values, int null_attribute);
-void range_close(Range *rng, int end_pos);
-void range_open(Range *rng, int start_pos, char *annot);
+void range_print_registry_line(SAttEncoder *rng, FILE *fd, int print_comment);
+SAttEncoder *range_declare(char *name, char *directory, int store_values, int null_attribute);
+void range_close(SAttEncoder *rng, int end_pos);
+void range_open(SAttEncoder *rng, int start_pos, char *annot);
 int wattr_find(char *name);
 int wattr_declare(char *name, char *directory, int nr_buckets);
 void wattr_close_all(void);
