@@ -8,7 +8,7 @@ test_that(
     token <- cl_id2str(
       corpus = "REUTERS",
       p_attribute = "word",
-      registry = system.file(package = "RcppCWB", "extdata", "cwb", "registry"),
+      registry = use_tmp_registry(),
       id = 0L:5L
     )
     expect_equal(token, c("Diamond", "Shamrock", "Corp", "said", "that", "effective"))
