@@ -8,7 +8,7 @@ test_that(
     cpos <- cl_struc2cpos(
       corpus = "REUTERS",
       s_attribute = "places",
-      registry = system.file(package = "RcppCWB", "extdata", "cwb", "registry"),
+      registry = get_tmp_registry(),
       struc = 1L
     )
     expect_equal(cpos, c(92L, 535L))
